@@ -57,6 +57,11 @@ struct wlr_pointer_constraint_v1 {
 	struct wl_list link; // wlr_pointer_constraints_v1::constraints
 
 	struct {
+		/**
+		 * Called when a pointer constraint's region is updated,
+		 * post-surface-commit.
+		 */
+		struct wl_signal set_region;
 		struct wl_signal destroy;
 	} events;
 
@@ -64,8 +69,8 @@ struct wlr_pointer_constraint_v1 {
 };
 
 struct wlr_pointer_constraints_v1 {
-	struct wl_list resources; // wl_resource_get_link
 	struct wl_global *global;
+	struct wl_list constraints; // wlr_pointer_constraint_v1::link
 
 	struct {
 		/**
@@ -76,15 +81,13 @@ struct wlr_pointer_constraints_v1 {
 		struct wl_signal new_constraint;
 	} events;
 
-	struct wl_list constraints; // wlr_pointer_constraint_v1::link
+	struct wl_listener display_destroy;
 
 	void *data;
 };
 
 struct wlr_pointer_constraints_v1 *wlr_pointer_constraints_v1_create(
 	struct wl_display *display);
-void wlr_pointer_constraints_v1_destroy(
-	struct wlr_pointer_constraints_v1 *pointer_constraints);
 
 struct wlr_pointer_constraint_v1 *
 	wlr_pointer_constraints_v1_constraint_for_surface(
